@@ -26,8 +26,8 @@ from datetime import datetime
 #             Image and array manipulation
 #------------------------------------------------------------------------
 lossYearPalette =  'ffffe5,fff7bc,fee391,fec44f,fe9929,ec7014,cc4c02'
-lossMagPalette = 'D00,F5DEB3'
-gainYearPalette =  'AFDEA8,80C476,308023,145B09'
+lossMagPalette = 'F5DEB3,D00'
+gainYearPalette =  'c5ee93,00a398'
 gainMagPalette = 'F5DEB3,006400'
 changeDurationPalette = 'BD1600,E2F400,0C2780'
 #Helper to multiply image
