@@ -1,3 +1,19 @@
+"""
+   Copyright 2021 Ian Housman
+
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+"""
+
 #Example of how to utilize the Python visualization tools
 #Uses the several stock GEE assets to show time series as a time lapse
 #Then uses those to color the raster and create a legend using the addToClassLegend option setting it to True
@@ -10,7 +26,9 @@
 import os,sys
 sys.path.append(os.getcwd())
 
-from geeViz.getImagesLib import *
+import  geeViz.geeView as geeView
+ee = geeView.ee
+Map = geeView.Map
 Map.clearMap()
 ####################################################################################################
 #Bring in pre-defined area
